@@ -1,8 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
- *
- * libtracker-gtk/tracker-utils.c - Grab bag of functions for manuipulating 
- * tracker results into more Gtk friedly types.
- *
+/*
  * Copyright (C) 2007 John Stowers
  *
  * This library is free software; you can redistribute it and/or
@@ -47,10 +43,15 @@ tracker_keyword_array_to_glist (gchar **array)
 GList *
 tracker_get_all_keywords (TrackerClient *tracker_client)
 {
+#if 0
 	GPtrArray *out_array;
+#endif
+
 	GList *list = NULL;
 	GError *error = NULL;
 
+	/* TODO: Port to SPARQL */
+#if 0
 	out_array = tracker_keywords_get_list (tracker_client, SERVICE_FILES, &error);
 
 	if (!error && out_array) {
@@ -66,39 +67,40 @@ tracker_get_all_keywords (TrackerClient *tracker_client)
 		}
 		g_ptr_array_free (out_array, TRUE);
 	}
+#endif
 
 	g_clear_error (&error);
 
 	return list;
 }
 
-/* Creates a tree model containing the keywords in List 
-this simple treemodel has a single column containing the keyword name*/
+/* Creates a tree model containing the keywords in List
+   this simple treemodel has a single column containing the keyword name*/
 GtkTreeModel *
 tracker_create_simple_keyword_liststore (const GList *list)
 {
-    GtkListStore *store;
-    const GList *tmp;
+	GtkListStore *store;
+	const GList *tmp;
 
-    store = gtk_list_store_new (1, G_TYPE_STRING);
+	store = gtk_list_store_new (1, G_TYPE_STRING);
 
-    for (tmp = list; tmp; tmp = tmp->next) {
-	    gchar *keyword = keyword = tmp->data;
+	for (tmp = list; tmp; tmp = tmp->next) {
+		gchar *keyword = keyword = tmp->data;
 
-	    gtk_list_store_insert_with_values (store,
-					       NULL,
-					       0,
-					       0,
-					       keyword,
-					       -1);
-    }
+		gtk_list_store_insert_with_values (store,
+		                                   NULL,
+		                                   0,
+		                                   0,
+		                                   keyword,
+		                                   -1);
+	}
 
-    return GTK_TREE_MODEL (store);
+	return GTK_TREE_MODEL (store);
 }
 
 void
 tracker_set_atk_relationship(GtkWidget *obj1, int relation_type,
-			     GtkWidget *obj2)
+                             GtkWidget *obj2)
 {
 	AtkObject *atk_obj1, *atk_obj2, *targets[1];
 	AtkRelationSet *atk_rel_set;
