@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia
@@ -28,9 +27,10 @@
 
 G_BEGIN_DECLS
 
-gboolean tracker_dbus_init            (void);
-void     tracker_dbus_shutdown        (void);
-gboolean tracker_dbus_register_object (void);
+gboolean tracker_dbus_init             (void);
+void     tracker_dbus_shutdown         (void);
+gboolean tracker_dbus_register_objects (gpointer object);
+GObject *tracker_dbus_get_object       (GType    type);
 
 G_END_DECLS
 
