@@ -1,5 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* Tracker Extract - extracts embedded metadata from files
+/*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia
  *
@@ -35,7 +34,6 @@
 
 #include <libtracker-common/tracker-ontology.h>
 #include <libtracker-common/tracker-type-utils.h>
-#include <libtracker-common/tracker-statement-list.h>
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-utils.h>
 
@@ -44,7 +42,7 @@
 #include "tracker-iptc.h"
 #include "tracker-exif.h"
 
-#define EXIF_DATE_FORMAT	"%Y:%m:%d %H:%M:%S"
+#define EXIF_DATE_FORMAT        "%Y:%m:%d %H:%M:%S"
 
 #define NMM_PREFIX TRACKER_NMM_PREFIX
 #define NFO_PREFIX TRACKER_NFO_PREFIX
@@ -63,15 +61,15 @@ typedef enum {
 } TagType;
 
 typedef struct {
-	gchar *camera, *title, *orientation, *copyright, *white_balance, 
-	      *fnumber, *flash, *focal_length, *artist, 
-	      *exposure_time, *iso_speed_ratings, *date, *description,
-	      *metering_mode, *creator, *x_dimension, *y_dimension;
+	gchar *camera, *title, *orientation, *copyright, *white_balance,
+		*fnumber, *flash, *focal_length, *artist,
+		*exposure_time, *iso_speed_ratings, *date, *description,
+		*metering_mode, *creator, *x_dimension, *y_dimension;
 } TiffNeedsMergeData;
 
 typedef struct {
 	gchar *artist, *copyright, *datetime, *documentname, *imagedescription,
-	      *imagewidth, *imagelength, *make, *model, *orientation;
+		*imagewidth, *imagelength, *make, *model, *orientation;
 } TiffData;
 
 static void extract_tiff (const gchar *filename,
@@ -89,24 +87,24 @@ get_flash (TIFF *image)
 
 	if (TIFFGetField (image, EXIFTAG_FLASH, &varui16)) {
 		switch (varui16) {
-			case 0x0001:
-			case 0x0009:
-			case 0x000D:
-			case 0x000F:
-			case 0x0019:
-			case 0x001D:
-			case 0x001F:
-			case 0x0041:
-			case 0x0045:
-			case 0x0047:
-			case 0x0049:
-			case 0x004D:
-			case 0x004F:
-			case 0x0059:
-			case 0x005F:
-			case 0x005D:
+		case 0x0001:
+		case 0x0009:
+		case 0x000D:
+		case 0x000F:
+		case 0x0019:
+		case 0x001D:
+		case 0x001F:
+		case 0x0041:
+		case 0x0045:
+		case 0x0047:
+		case 0x0049:
+		case 0x004D:
+		case 0x004F:
+		case 0x0059:
+		case 0x005F:
+		case 0x005D:
 			return g_strdup ("nmm:flash-on");
-			default:
+		default:
 			return g_strdup ("nmm:flash-off");
 		}
 	}
@@ -121,22 +119,22 @@ get_orientation (TIFF *image)
 
 	if (TIFFGetField (image, TIFFTAG_ORIENTATION, &varui16)) {
 		switch (varui16) {
-			default:
-			case 0:
+		default:
+		case 0:
 			return  g_strdup ("nfo:orientation-top");
-			case 1:
+		case 1:
 			return  g_strdup ("nfo:orientation-top-mirror");
-			case 2:
+		case 2:
 			return  g_strdup ("nfo:orientation-bottom");
-			case 3:
+		case 3:
 			return  g_strdup ("nfo:orientation-bottom-mirror");
-			case 4:
+		case 4:
 			return  g_strdup ("nfo:orientation-left-mirror");
-			case 5:
+		case 5:
 			return  g_strdup ("nfo:orientation-right");
-			case 6:
+		case 6:
 			return  g_strdup ("nfo:orientation-right-mirror");
-			case 7:
+		case 7:
 			return  g_strdup ("nfo:orientation-left");
 		}
 	}
@@ -152,19 +150,19 @@ get_metering_mode (TIFF *image)
 
 	if (TIFFGetField (image, EXIFTAG_METERINGMODE, &varui16)) {
 		switch (varui16) {
-			case 1:
+		case 1:
 			return g_strdup ("nmm:meteringMode-average");
-			case 2:
+		case 2:
 			return g_strdup ("nmm:meteringMode-center-weighted-average");
-			case 3:
+		case 3:
 			return g_strdup ("nmm:meteringMode-spot");
-			case 4:
+		case 4:
 			return g_strdup ("nmm:meteringMode-multispot");
-			case 5:
+		case 5:
 			return g_strdup ("nmm:meteringMode-pattern");
-			case 6:
+		case 6:
 			return g_strdup ("nmm:meteringMode-partial");
-			default:
+		default:
 			return g_strdup ("nmm:meteringMode-other");
 		}
 	}
@@ -201,33 +199,33 @@ get_value (TIFF *image, guint tag, guint type)
 	void *data = NULL;
 
 	switch (type) {
-		case TIFF_TAGTYPE_STRING:
-			if (TIFFGetField (image, tag, &text)) {
-				return g_strdup (text);
-			}
-			break;
-		case TIFF_TAGTYPE_UINT16:
-			if (TIFFGetField (image, tag, &varui16)) {
-				return g_strdup_printf ("%i", varui16);
-			}
-			break;
-		case TIFF_TAGTYPE_UINT32:
-			if (TIFFGetField (image, tag, &varui32)) {
-				return g_strdup_printf ("%i", varui32);
-			}
-			break;
-		case TIFF_TAGTYPE_DOUBLE:
-			if (TIFFGetField (image, tag, &vardouble)) {
-				return g_strdup_printf ("%f", vardouble);
-			}
-			break;
-		case TIFF_TAGTYPE_C16_UINT16:
-			if (TIFFGetField (image, tag, &count16, &data)) {
-				return g_strdup_printf ("%i", * (guint16 *) data);
-			}
-			break;
-		default:
-			break;
+	case TIFF_TAGTYPE_STRING:
+		if (TIFFGetField (image, tag, &text)) {
+			return g_strdup (text);
+		}
+		break;
+	case TIFF_TAGTYPE_UINT16:
+		if (TIFFGetField (image, tag, &varui16)) {
+			return g_strdup_printf ("%i", varui16);
+		}
+		break;
+	case TIFF_TAGTYPE_UINT32:
+		if (TIFFGetField (image, tag, &varui32)) {
+			return g_strdup_printf ("%i", varui32);
+		}
+		break;
+	case TIFF_TAGTYPE_DOUBLE:
+		if (TIFFGetField (image, tag, &vardouble)) {
+			return g_strdup_printf ("%f", vardouble);
+		}
+		break;
+	case TIFF_TAGTYPE_C16_UINT16:
+		if (TIFFGetField (image, tag, &count16, &data)) {
+			return g_strdup_printf ("%i", * (guint16 *) data);
+		}
+		break;
+	default:
+		break;
 	}
 
 	return NULL;
@@ -244,18 +242,25 @@ insert_keywords (TrackerSparqlBuilder *metadata, const gchar *uri, gchar *keywor
 	keywords = strchr (keywords, '"');
 	if (keywords)
 		keywords++;
-	else 
+	else
 		keywords = keyw;
 
 	len = strlen (keywords);
 	if (keywords[len - 1] == '"')
 		keywords[len - 1] = '\0';
 
-	for (keyw = strtok_r (keywords, ",; ", &lasts); keyw; 
+	for (keyw = strtok_r (keywords, ",; ", &lasts); keyw;
 	     keyw = strtok_r (NULL, ",; ", &lasts)) {
-		tracker_statement_list_insert (metadata, uri, 
-		                               NIE_PREFIX "keyword", 
-		                               (const gchar*) keyw);
+		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
+
+		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nao:Tag");
+
+		tracker_sparql_builder_predicate (metadata, "nao:prefLabel");
+		tracker_sparql_builder_object_unvalidated (metadata, keyw);
+
+		tracker_sparql_builder_object_blank_close (metadata);
 	}
 }
 
@@ -287,21 +292,18 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 		return;
 	}
 
-	tracker_statement_list_insert (metadata, uri, 
-	                               RDF_PREFIX "type",
-	                               NFO_PREFIX "Image");
-
-	tracker_statement_list_insert (metadata, uri,
-	                               RDF_PREFIX "type",
-	                               NMM_PREFIX "Photo");
+	tracker_sparql_builder_subject_iri (metadata, uri);
+	tracker_sparql_builder_predicate (metadata, "a");
+	tracker_sparql_builder_object (metadata, "nfo:Image");
+	tracker_sparql_builder_object (metadata, "nmm:Photo");
 
 #ifdef HAVE_LIBIPTCDATA
 	if (TIFFGetField (image, TIFFTAG_RICHTIFFIPTC, &iptcSize, &iptcOffset)) {
-		if (TIFFIsByteSwapped(image) != 0) 
+		if (TIFFIsByteSwapped(image) != 0)
 			TIFFSwabArrayOfLong((uint32 *) iptcOffset,(unsigned long) iptcSize);
 		tracker_read_iptc (iptcOffset,
-				   4*iptcSize,
-				   uri, &iptc_data);
+		                   4*iptcSize,
+		                   uri, &iptc_data);
 	}
 #endif /* HAVE_LIBIPTCDATA */
 
@@ -310,9 +312,9 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 #ifdef HAVE_EXEMPI
 	if (TIFFGetField (image, TIFFTAG_XMLPACKET, &size, &xmpOffset)) {
 		tracker_read_xmp (xmpOffset,
-				  size,
-				  uri,
-				  &xmp_data);
+		                  size,
+		                  uri,
+		                  &xmp_data);
 	}
 #endif /* HAVE_EXEMPI */
 
@@ -320,36 +322,36 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 		tiff_data.artist = get_value (image, TIFFTAG_ARTIST, TIFF_TAGTYPE_STRING);
 	if (!tiff_data.copyright)
 		tiff_data.copyright = get_value (image, TIFFTAG_COPYRIGHT, TIFF_TAGTYPE_STRING);
-	if (!tiff_data.datetime) 
-		tiff_data.datetime = get_value (image, TIFFTAG_DATETIME, TIFF_TAGTYPE_STRING); 
-	if (!tiff_data.documentname) 
-		tiff_data.documentname = get_value (image, TIFFTAG_DOCUMENTNAME, TIFF_TAGTYPE_STRING); 
-	if (!tiff_data.imagedescription) 
-		tiff_data.imagedescription = get_value (image, TIFFTAG_IMAGEDESCRIPTION, TIFF_TAGTYPE_STRING); 
-	if (!tiff_data.make) 
-		tiff_data.make = get_value (image, TIFFTAG_MAKE, TIFF_TAGTYPE_STRING); 
-	if (!tiff_data.model) 
-		tiff_data.model = get_value (image, TIFFTAG_MODEL, TIFF_TAGTYPE_STRING); 
+	if (!tiff_data.datetime)
+		tiff_data.datetime = get_value (image, TIFFTAG_DATETIME, TIFF_TAGTYPE_STRING);
+	if (!tiff_data.documentname)
+		tiff_data.documentname = get_value (image, TIFFTAG_DOCUMENTNAME, TIFF_TAGTYPE_STRING);
+	if (!tiff_data.imagedescription)
+		tiff_data.imagedescription = get_value (image, TIFFTAG_IMAGEDESCRIPTION, TIFF_TAGTYPE_STRING);
+	if (!tiff_data.make)
+		tiff_data.make = get_value (image, TIFFTAG_MAKE, TIFF_TAGTYPE_STRING);
+	if (!tiff_data.model)
+		tiff_data.model = get_value (image, TIFFTAG_MODEL, TIFF_TAGTYPE_STRING);
 	if (!tiff_data.orientation)
-		tiff_data.orientation = get_orientation (image); 
+		tiff_data.orientation = get_orientation (image);
 
 	if (TIFFGetField (image, TIFFTAG_EXIFIFD, &exifOffset)) {
 		if (TIFFReadEXIFDirectory (image, exifOffset)) {
 			if (!exif_data.exposure_time)
-				exif_data.exposure_time = get_value (image, EXIFTAG_EXPOSURETIME, TIFF_TAGTYPE_DOUBLE); 
+				exif_data.exposure_time = get_value (image, EXIFTAG_EXPOSURETIME, TIFF_TAGTYPE_DOUBLE);
 			if (!exif_data.fnumber)
-				exif_data.fnumber = get_value (image, EXIFTAG_FNUMBER, TIFF_TAGTYPE_DOUBLE); 
+				exif_data.fnumber = get_value (image, EXIFTAG_FNUMBER, TIFF_TAGTYPE_DOUBLE);
 			if (!exif_data.iso_speed_ratings)
-				exif_data.iso_speed_ratings = get_value (image, EXIFTAG_ISOSPEEDRATINGS, TIFF_TAGTYPE_C16_UINT16); 
+				exif_data.iso_speed_ratings = get_value (image, EXIFTAG_ISOSPEEDRATINGS, TIFF_TAGTYPE_C16_UINT16);
 			if (!exif_data.time_original)
-				exif_data.time_original = get_value (image, EXIFTAG_DATETIMEORIGINAL, TIFF_TAGTYPE_STRING); 
+				exif_data.time_original = get_value (image, EXIFTAG_DATETIMEORIGINAL, TIFF_TAGTYPE_STRING);
 			if (!exif_data.metering_mode)
-				exif_data.metering_mode = get_metering_mode (image); 
+				exif_data.metering_mode = get_metering_mode (image);
 			if (!exif_data.flash)
-				exif_data.flash = get_flash (image); 
+				exif_data.flash = get_flash (image);
 			if (!exif_data.focal_length)
-				exif_data.focal_length = get_value (image, EXIFTAG_DATETIMEORIGINAL, TIFF_TAGTYPE_DOUBLE); 
-			if (!exif_data.white_balance) 
+				exif_data.focal_length = get_value (image, EXIFTAG_DATETIMEORIGINAL, TIFF_TAGTYPE_DOUBLE);
+			if (!exif_data.white_balance)
 				exif_data.white_balance = get_white_balance (image);
 		}
 	}
@@ -379,7 +381,7 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	}
 
 	merge_data.title = tracker_coalesce (3, tiff_data.documentname,
-	                                     xmp_data.title,
+	                                     xmp_data.title, xmp_data.Title,
 	                                     exif_data.document_name);
 
 	merge_data.orientation = tracker_coalesce (4, tiff_data.orientation,
@@ -394,7 +396,7 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 
 	merge_data.white_balance = tracker_coalesce (2, exif_data.white_balance,
 	                                             xmp_data.WhiteBalance);
-	                                             
+
 
 	merge_data.fnumber =  tracker_coalesce (2, exif_data.fnumber,
 	                                        xmp_data.FNumber);
@@ -417,7 +419,7 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	                                                  xmp_data.ISOSpeedRatings);
 
 	merge_data.date =  tracker_coalesce (6, tiff_data.datetime,
-	                                     exif_data.time, 
+	                                     exif_data.time,
 	                                     xmp_data.date,
 	                                     iptc_data.date_created,
 	                                     exif_data.time_original,
@@ -440,17 +442,20 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	                                            exif_data.y_dimension);
 
 	if (exif_data.user_comment) {
-		tracker_statement_list_insert (metadata, uri, NIE_PREFIX "comment", exif_data.user_comment);
+		tracker_sparql_builder_predicate (metadata, "nie:comment");
+		tracker_sparql_builder_object_unvalidated (metadata, exif_data.user_comment);
 		g_free (exif_data.user_comment);
 	}
 
 	if (merge_data.x_dimension) {
-		tracker_statement_list_insert (metadata, uri, NFO_PREFIX "width", merge_data.x_dimension);
+		tracker_sparql_builder_predicate (metadata, "nfo:width");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.x_dimension);
 		g_free (merge_data.x_dimension);
 	}
 
 	if (merge_data.y_dimension) {
-		tracker_statement_list_insert (metadata, uri, NFO_PREFIX "height", merge_data.y_dimension);
+		tracker_sparql_builder_predicate (metadata, "nfo:height");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.y_dimension);
 		g_free (merge_data.y_dimension);
 	}
 
@@ -465,49 +470,63 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	}
 
 	if (xmp_data.publisher) {
-		tracker_statement_list_insert (metadata, ":", RDF_PREFIX "type", NCO_PREFIX "Contact");
-		tracker_statement_list_insert (metadata, ":", NCO_PREFIX "fullname", xmp_data.publisher);
-		tracker_statement_list_insert (metadata, uri, NCO_PREFIX "publisher", ":");
+		tracker_sparql_builder_predicate (metadata, "nco:publisher");
+
+		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nco:Contact");
+
+		tracker_sparql_builder_predicate (metadata, "nco:fullname");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.publisher);
+		tracker_sparql_builder_object_blank_close (metadata);
 		g_free (xmp_data.publisher);
 	}
 
 	if (xmp_data.type) {
-		tracker_statement_list_insert (metadata, uri, DC_PREFIX "type", xmp_data.type);
+		tracker_sparql_builder_predicate (metadata, "dc:type");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.type);
 		g_free (xmp_data.type);
 	}
 
 	if (xmp_data.format) {
-		tracker_statement_list_insert (metadata, uri, DC_PREFIX "format", xmp_data.format);
+		tracker_sparql_builder_predicate (metadata, "dc:format");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.format);
 		g_free (xmp_data.format);
 	}
 
 	if (xmp_data.identifier) {
-		tracker_statement_list_insert (metadata, uri, DC_PREFIX "identifier", xmp_data.identifier);
+		tracker_sparql_builder_predicate (metadata, "dc:identifier");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.identifier);
 		g_free (xmp_data.identifier);
 	}
 
 	if (xmp_data.source) {
-		tracker_statement_list_insert (metadata, uri, DC_PREFIX "source", xmp_data.source);
+		tracker_sparql_builder_predicate (metadata, "dc:source");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.source);
 		g_free (xmp_data.source);
 	}
 
 	if (xmp_data.language) {
-		tracker_statement_list_insert (metadata, uri, DC_PREFIX "language", xmp_data.language);
+		tracker_sparql_builder_predicate (metadata, "dc:language");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.language);
 		g_free (xmp_data.language);
 	}
 
 	if (xmp_data.relation) {
-		tracker_statement_list_insert (metadata, uri, DC_PREFIX "relation", xmp_data.relation);
+		tracker_sparql_builder_predicate (metadata, "dc:relation");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.relation);
 		g_free (xmp_data.relation);
 	}
 
 	if (xmp_data.coverage) {
-		tracker_statement_list_insert (metadata, uri, DC_PREFIX "coverage", xmp_data.coverage);
+		tracker_sparql_builder_predicate (metadata, "dc:coverage");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.coverage);
 		g_free (xmp_data.coverage);
 	}
 
 	if (xmp_data.license) {
-		tracker_statement_list_insert (metadata, uri, NIE_PREFIX "license", xmp_data.license);
+		tracker_sparql_builder_predicate (metadata, "nie:license");
+		tracker_sparql_builder_object_unvalidated (metadata, xmp_data.license);
 		g_free (xmp_data.license);
 	}
 
@@ -517,81 +536,106 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 	}
 
 	if (merge_data.camera) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "camera", merge_data.camera);
+		tracker_sparql_builder_predicate (metadata, "nmm:camera");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.camera);
 		g_free (merge_data.camera);
 	}
 
 	if (merge_data.title) {
-		tracker_statement_list_insert (metadata, uri, NIE_PREFIX "title", merge_data.title);
+		tracker_sparql_builder_predicate (metadata, "nie:title");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.title);
 		g_free (merge_data.title);
 	}
 
 	if (merge_data.orientation) {
-		tracker_statement_list_insert (metadata, uri, NFO_PREFIX "orientation", merge_data.orientation);
+		tracker_sparql_builder_predicate (metadata, "nfo:orientation");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.orientation);
 		g_free (merge_data.orientation);
 	}
 
 	if (merge_data.copyright) {
-		tracker_statement_list_insert (metadata, uri, NIE_PREFIX "copyright", merge_data.copyright);
+		tracker_sparql_builder_predicate (metadata, "nie:copyright");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.copyright);
 		g_free (merge_data.copyright);
 	}
 
 	if (merge_data.white_balance) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "whiteBalance", merge_data.white_balance);
+		tracker_sparql_builder_predicate (metadata, "nmm:whiteBalance");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.white_balance);
 		g_free (merge_data.white_balance);
 	}
 
 	if (merge_data.fnumber) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "fnumber", merge_data.fnumber);
+		tracker_sparql_builder_predicate (metadata, "nmm:fnumber");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.fnumber);
 		g_free (merge_data.fnumber);
 	}
 
 	if (merge_data.flash) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "flash", merge_data.flash);
+		tracker_sparql_builder_predicate (metadata, "nmm:flash");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.flash);
 		g_free (merge_data.flash);
 	}
 
 	if (merge_data.focal_length) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "focalLength", merge_data.focal_length);
+		tracker_sparql_builder_predicate (metadata, "nmm:focalLength");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.focal_length);
 		g_free (merge_data.focal_length);
 	}
 
 	if (merge_data.artist) {
-		tracker_statement_list_insert (metadata, ":", RDF_PREFIX "type", NCO_PREFIX "Contact");
-		tracker_statement_list_insert (metadata, ":", NCO_PREFIX "fullname", merge_data.artist);
-		tracker_statement_list_insert (metadata, uri, NCO_PREFIX "contributor", ":");
+		tracker_sparql_builder_predicate (metadata, "nco:contributor");
+
+		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nco:Contact");
+
+		tracker_sparql_builder_predicate (metadata, "nco:fullname");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.artist);
+		tracker_sparql_builder_object_blank_close (metadata);
 		g_free (merge_data.artist);
 	}
 
 	if (merge_data.exposure_time) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "exposureTime", merge_data.exposure_time);
+		tracker_sparql_builder_predicate (metadata, "nmm:exposureTime");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.exposure_time);
 		g_free (merge_data.exposure_time);
 	}
 
 	if (merge_data.iso_speed_ratings) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "isoSpeed", merge_data.iso_speed_ratings);
+		tracker_sparql_builder_predicate (metadata, "nmm:isoSpeed");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.iso_speed_ratings);
 		g_free (merge_data.iso_speed_ratings);
 	}
 
 	if (merge_data.date) {
-		tracker_statement_list_insert (metadata, uri, NIE_PREFIX "contentCreated", merge_data.date);
+		tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.date);
 		g_free (merge_data.date);
 	}
 
 	if (merge_data.description) {
-		tracker_statement_list_insert (metadata, uri, NIE_PREFIX "description", merge_data.description);
+		tracker_sparql_builder_predicate (metadata, "nie:description");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.description);
 		g_free (merge_data.description);
 	}
 
 	if (merge_data.metering_mode) {
-		tracker_statement_list_insert (metadata, uri, NMM_PREFIX "meteringMode", merge_data.metering_mode);
+		tracker_sparql_builder_predicate (metadata, "nmm:meteringMode");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.metering_mode);
 		g_free (merge_data.metering_mode);
 	}
 
 	if (merge_data.creator) {
-		tracker_statement_list_insert (metadata, ":", RDF_PREFIX "type", NCO_PREFIX "Contact");
-		tracker_statement_list_insert (metadata, ":", NCO_PREFIX "fullname", merge_data.creator);
-		tracker_statement_list_insert (metadata, uri, NCO_PREFIX "creator", ":");
+		tracker_sparql_builder_predicate (metadata, "nco:creator");
+
+		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nco:Contact");
+
+		tracker_sparql_builder_predicate (metadata, "nco:fullname");
+		tracker_sparql_builder_object_unvalidated (metadata, merge_data.creator);
+		tracker_sparql_builder_object_blank_close (metadata);
 		g_free (merge_data.creator);
 	}
 }
