@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2009, Nokia
  *
@@ -31,22 +30,22 @@
 #include <libtracker-client/tracker.h>
 #include <libtracker-common/tracker-common.h>
 
-#define ABOUT                                                             \
-        "Tracker " PACKAGE_VERSION "\n"
+#define ABOUT	  \
+	"Tracker " PACKAGE_VERSION "\n"
 
-#define LICENSE                                                           \
-        "This program is free software and comes without any warranty.\n" \
-        "It is licensed under version 2 or later of the General Public "  \
-        "License which can be viewed at:\n"                               \
-        "\n"                                                              \
-        "  http://www.gnu.org/licenses/gpl.txt\n"
+#define LICENSE	  \
+	"This program is free software and comes without any warranty.\n" \
+	"It is licensed under version 2 or later of the General Public " \
+	"License which can be viewed at:\n" \
+	"\n" \
+	"  http://www.gnu.org/licenses/gpl.txt\n"
 
-static gint	     limit = 512;
-static gint	     offset;
-static gchar	   **files;
+static gint          limit = 512;
+static gint          offset;
+static gchar       **files;
 static gboolean      or_operator;
-static gchar	    *add_tag;
-static gchar	    *remove_tag;
+static gchar        *add_tag;
+static gchar        *remove_tag;
 static gboolean     *list;
 static gboolean      show_files;
 static gboolean      print_version;
@@ -84,7 +83,7 @@ static GOptionEntry entries[] = {
 	  N_("Print version"),
 	  NULL
 	},
-	{ G_OPTION_REMAINING, 0, 
+	{ G_OPTION_REMAINING, 0,
 	  G_OPTION_FLAG_FILENAME,
 	  G_OPTION_ARG_STRING_ARRAY, &files,
 	  N_("FILE…"),
@@ -99,12 +98,12 @@ show_limit_warning (void)
 	 * more items.
 	 */
 	g_print ("  ...\n");
-	
+
 	/* Display warning so the user knows this is
 	 * not the WHOLE data set.
 	 */
 	g_printerr ("\n%s\n",
-		    _("NOTE: Limit was reached, there are more items in the database not listed here"));
+	            _("NOTE: Limit was reached, there are more items in the database not listed here"));
 }
 
 static gchar *
@@ -113,43 +112,43 @@ get_escaped_sparql_string (const gchar *str)
 	GString *sparql;
 
 	sparql = g_string_new ("");
-        g_string_append_c (sparql, '"');
+	g_string_append_c (sparql, '"');
 
-        while (*str != '\0') {
-                gsize len = strcspn (str, "\t\n\r\"\\");
-                g_string_append_len (sparql, str, len);
-                str += len;
-                switch (*str) {
-                case '\t':
-                        g_string_append (sparql, "\\t");
-                        break;
-                case '\n':
-                        g_string_append (sparql, "\\n");
-                        break;
-                case '\r':
-                        g_string_append (sparql, "\\r");
-                        break;
-                case '"':
-                        g_string_append (sparql, "\\\"");
-                        break;
-                case '\\':
-                        g_string_append (sparql, "\\\\");
-                        break;
-                default:
-                        continue;
-                }
-                str++;
-        }
+	while (*str != '\0') {
+		gsize len = strcspn (str, "\t\n\r\"\\");
+		g_string_append_len (sparql, str, len);
+		str += len;
+		switch (*str) {
+		case '\t':
+			g_string_append (sparql, "\\t");
+			break;
+		case '\n':
+			g_string_append (sparql, "\\n");
+			break;
+		case '\r':
+			g_string_append (sparql, "\\r");
+			break;
+		case '"':
+			g_string_append (sparql, "\\\"");
+			break;
+		case '\\':
+			g_string_append (sparql, "\\\\");
+			break;
+		default:
+			continue;
+		}
+		str++;
+	}
 
-        g_string_append_c (sparql, '"');
+	g_string_append_c (sparql, '"');
 
 	return g_string_free (sparql, FALSE);
 }
 
 static gchar *
 get_fts_string (GStrv    search_words,
-		gboolean use_or_operator,
-		gboolean for_regex)
+                gboolean use_or_operator,
+                gboolean for_regex)
 {
 	GString *fts;
 	gint i, len;
@@ -165,7 +164,7 @@ get_fts_string (GStrv    search_words,
 		g_string_append (fts, search_words[i]);
 		g_string_append_c (fts, '*');
 
-		if (i < len - 1) { 
+		if (i < len - 1) {
 			if (for_regex) {
 				if (use_or_operator) {
 					g_string_append (fts, " || ");
@@ -187,7 +186,7 @@ get_fts_string (GStrv    search_words,
 
 static gchar *
 get_filter_string (GStrv        files,
-		   const gchar *tag)
+                   const gchar *tag)
 {
 	GString *filter;
 	gint i, len;
@@ -211,9 +210,17 @@ get_filter_string (GStrv        files,
 	}
 
 	for (i = 0; i < len; i++) {
-		g_string_append_printf (filter, "?f = <%s>", files[i]);
+		GFile *file;
+		gchar *uri;
 
-		if (i < len - 1) { 
+		file = g_file_new_for_commandline_arg (files[i]);
+		uri = g_file_get_uri (file);
+		g_object_unref (file);
+
+		g_string_append_printf (filter, "?f = <%s>", uri);
+		g_free (uri);
+
+		if (i < len - 1) {
 			g_string_append (filter, " || ");
 		}
 	}
@@ -229,7 +236,7 @@ get_filter_string (GStrv        files,
 
 static void
 get_all_tags_foreach (gpointer value,
-		      gpointer user_data)
+                      gpointer user_data)
 {
 	TrackerClient *client;
 	GError *error = NULL;
@@ -248,15 +255,15 @@ get_all_tags_foreach (gpointer value,
 	tag = data[1];
 
 	g_print ("  %s\n", tag);
-	
+
 	g_print ("    %s\n", id);
 
 	g_print ("    ");
 	g_print (tracker_dngettext (NULL,
-				    "%d file", 
-				    "%d files",
-				    files),
-		 files);
+	                            "%d file",
+	                            "%d files",
+	                            files),
+	         files);
 	g_print ("\n");
 
 	if (!client || files < 1) {
@@ -265,25 +272,25 @@ get_all_tags_foreach (gpointer value,
 
 	/* Get files associated */
 	query = g_strdup_printf ("SELECT ?urn WHERE {"
-				 "  ?urn a rdfs:Resource; "
-				 "  nao:hasTag \"%s\" "
-				 "}",
-				 id);
+	                         "  ?urn a rdfs:Resource; "
+	                         "  nao:hasTag \"%s\" "
+	                         "}",
+	                         id);
 
 	results = tracker_resources_sparql_query (client, query, &error);
 	g_free (query);
 
 	if (error) {
-		g_print ("    %s, %s\n", 
-			 _("Could not get files related to tag"),
-			 error->message);
+		g_print ("    %s, %s\n",
+		         _("Could not get files related to tag"),
+		         error->message);
 		g_error_free (error);
 		return;
 	}
 
 	for (i = 0; i < results->len; i++) {
 		GStrv files;
-		
+
 		files = g_ptr_array_index (results, i);
 		g_print ("    %s\n", files[0]);
 		g_strfreev (files);
@@ -294,11 +301,11 @@ get_all_tags_foreach (gpointer value,
 
 static gboolean
 get_all_tags (TrackerClient *client,
-	      GStrv          files,
-	      gint           search_offset,
-	      gint           search_limit,
-	      gboolean       use_or_operator,
-	      gboolean       show_files)
+              GStrv          files,
+              gint           search_offset,
+              gint           search_limit,
+              gboolean       use_or_operator,
+              gboolean       show_files)
 {
 	GError *error = NULL;
 	GPtrArray *results;
@@ -309,36 +316,36 @@ get_all_tags (TrackerClient *client,
 
 	if (fts) {
 		query = g_strdup_printf ("SELECT ?tag ?label COUNT(?urns) AS urns "
-					 "WHERE {" 
-					 "  ?tag a nao:Tag ;"
-					 "  nao:prefLabel ?label ."
-					 "  OPTIONAL {"
-					 "     ?urns nao:hasTag ?tag"
-					 "  } ."
-					 "  FILTER regex (?label, \"%s\")"
-					 "} "
-					 "GROUP BY ?tag "
-					 "ORDER BY ASC(?label) "
-					 "OFFSET %d "
-					 "LIMIT %d",
-					 fts,
-					 search_offset, 
-					 search_limit);
+		                         "WHERE {"
+		                         "  ?tag a nao:Tag ;"
+		                         "  nao:prefLabel ?label ."
+		                         "  OPTIONAL {"
+		                         "     ?urns nao:hasTag ?tag"
+		                         "  } ."
+		                         "  FILTER regex (?label, \"%s\")"
+		                         "} "
+		                         "GROUP BY ?tag "
+		                         "ORDER BY ASC(?label) "
+		                         "OFFSET %d "
+		                         "LIMIT %d",
+		                         fts,
+		                         search_offset,
+		                         search_limit);
 	} else {
 		query = g_strdup_printf ("SELECT ?tag ?label COUNT(?urns) AS urns "
-					 "WHERE {" 
-					 "  ?tag a nao:Tag ;"
-					 "  nao:prefLabel ?label ."
-					 "  OPTIONAL {"
-					 "     ?urns nao:hasTag ?tag"
-					 "  }"
-					 "} "
-					 "GROUP BY ?tag "
-					 "ORDER BY ASC(?label) "
-					 "OFFSET %d "
-					 "LIMIT %d",
-					 search_offset, 
-					 search_limit);
+		                         "WHERE {"
+		                         "  ?tag a nao:Tag ;"
+		                         "  nao:prefLabel ?label ."
+		                         "  OPTIONAL {"
+		                         "     ?urns nao:hasTag ?tag"
+		                         "  }"
+		                         "} "
+		                         "GROUP BY ?tag "
+		                         "ORDER BY ASC(?label) "
+		                         "OFFSET %d "
+		                         "LIMIT %d",
+		                         search_offset,
+		                         search_limit);
 	}
 
 	g_free (fts);
@@ -348,8 +355,8 @@ get_all_tags (TrackerClient *client,
 
 	if (error) {
 		g_printerr ("%s, %s\n",
-			    _("Could not get all tags"),
-			    error->message);
+		            _("Could not get all tags"),
+		            error->message);
 		g_error_free (error);
 
 		return FALSE;
@@ -357,18 +364,18 @@ get_all_tags (TrackerClient *client,
 
 	if (!results) {
 		g_print ("%s\n",
-			 _("No tags were found"));
+		         _("No tags were found"));
 	} else {
 		g_print (tracker_dngettext (NULL,
-					    "Tag: %d (shown by name)", 
-					    "Tags: %d (shown by name)",
-					    results->len),
-			 results->len);
+		                            "Tag: %d (shown by name)",
+		                            "Tags: %d (shown by name)",
+		                            results->len),
+		         results->len);
 		g_print ("\n");
 
-		g_ptr_array_foreach (results, 
-				     get_all_tags_foreach,
-				     show_files ? client : NULL);
+		g_ptr_array_foreach (results,
+		                     get_all_tags_foreach,
+		                     show_files ? client : NULL);
 
 		if (results->len >= search_limit) {
 			show_limit_warning ();
@@ -377,14 +384,14 @@ get_all_tags (TrackerClient *client,
 		g_ptr_array_foreach (results, (GFunc) g_strfreev, NULL);
 		g_ptr_array_free (results, TRUE);
 	}
-	
+
 	return TRUE;
 }
 
 static gboolean
 add_tag_for_urns (TrackerClient *client,
-		  GStrv          files,
-		  const gchar   *tag)
+                  GStrv          files,
+                  const gchar   *tag)
 {
 	GError *error = NULL;
 	gchar *filter;
@@ -398,45 +405,49 @@ add_tag_for_urns (TrackerClient *client,
 	 * is, then we add the urns specified to the new tag.
 	 */
 	if (filter) {
+
+		/* We use IE = DO, so we can optimize using nie:isStoredAs instead of
+	 	* nie:url here. Please change this when we change that decision. */
+
 		/* Add tag to specific urns */
 		query = g_strdup_printf ("INSERT { "
-					 "  _:tag a nao:Tag;"
-					 "  nao:prefLabel %s ."
-					 "} "
-					 "WHERE {"
-					 "  OPTIONAL {"
-					 "     ?tag a nao:Tag ;"
-					 "     nao:prefLabel %s"
-					 "  } ."
-					 "  FILTER (!bound(?tag)) "
-					 "} "
-					 "INSERT { "
-					 "  ?urn nao:hasTag ?id "
-					 "} "
-					 "WHERE {"
-					 "  ?urn nie:isStoredAs ?f ."
-					 "  ?id nao:prefLabel %s "
-					 "  %s "
-					 "}",
-					 tag_escaped,
-					 tag_escaped,
-					 tag_escaped,
-					 filter);
+		                         "  _:tag a nao:Tag;"
+		                         "  nao:prefLabel %s ."
+		                         "} "
+		                         "WHERE {"
+		                         "  OPTIONAL {"
+		                         "     ?tag a nao:Tag ;"
+		                         "     nao:prefLabel %s"
+		                         "  } ."
+		                         "  FILTER (!bound(?tag)) "
+		                         "} "
+		                         "INSERT { "
+		                         "  ?urn nao:hasTag ?id "
+		                         "} "
+		                         "WHERE {"
+		                         "  ?urn nie:isStoredAs ?f ."
+		                         "  ?id nao:prefLabel %s "
+		                         "  %s "
+		                         "}",
+		                         tag_escaped,
+		                         tag_escaped,
+		                         tag_escaped,
+		                         filter);
 	} else {
 		/* Add tag and do not link it to urns */
 		query = g_strdup_printf ("INSERT { "
-					 "  _:tag a nao:Tag;"
-					 "  nao:prefLabel %s ."
-					 "} "
-					 "WHERE {"
-					 "  OPTIONAL {"
-					 "     ?tag a nao:Tag ;"
-					 "     nao:prefLabel %s"
-					 "  } ."
-					 "  FILTER (!bound(?tag)) "
-					 "}",
-					 tag_escaped,
-					 tag_escaped);
+		                         "  _:tag a nao:Tag;"
+		                         "  nao:prefLabel %s ."
+		                         "} "
+		                         "WHERE {"
+		                         "  OPTIONAL {"
+		                         "     ?tag a nao:Tag ;"
+		                         "     nao:prefLabel %s"
+		                         "  } ."
+		                         "  FILTER (!bound(?tag)) "
+		                         "}",
+		                         tag_escaped,
+		                         tag_escaped);
 	}
 
 	g_free (tag_escaped);
@@ -447,23 +458,23 @@ add_tag_for_urns (TrackerClient *client,
 
 	if (error) {
 		g_printerr ("%s, %s\n",
-			    _("Could not add tag"),
-			    error->message);
+		            _("Could not add tag"),
+		            error->message);
 		g_error_free (error);
 
 		return FALSE;
 	}
 
 	g_print ("%s\n",
-		 _("Tag was added successfully"));
+	         _("Tag was added successfully"));
 
 	return TRUE;
 }
 
 static gboolean
 remove_tag_for_urns (TrackerClient *client,
-		     GStrv          files,
-		     const gchar   *tag)
+                     GStrv          files,
+                     const gchar   *tag)
 {
 	GError *error = NULL;
 	gchar *tag_escaped;
@@ -478,28 +489,28 @@ remove_tag_for_urns (TrackerClient *client,
 
 		/* Get all tags urns */
 		query = g_strdup_printf ("SELECT ?tag "
-					 "WHERE {"
-					 "  ?tag a nao:Tag ."
-					 "  ?tag nao:prefLabel %s "
-					 "}",
-					 tag_escaped);
+		                         "WHERE {"
+		                         "  ?tag a nao:Tag ."
+		                         "  ?tag nao:prefLabel %s "
+		                         "}",
+		                         tag_escaped);
 
 		results = tracker_resources_sparql_query (client, query, &error);
 		g_free (query);
 
 		if (error) {
 			g_printerr ("%s, %s\n",
-				    _("Could not get tag by label"),
-				    error->message);
+			            _("Could not get tag by label"),
+			            error->message);
 			g_error_free (error);
 			g_free (tag_escaped);
 
 			return FALSE;
 		}
-		
+
 		if (!results || !results->pdata || !results->pdata[0]) {
 			g_print ("%s\n",
-				 _("No tags were found by that name"));
+			         _("No tags were found by that name"));
 
 			g_free (tag_escaped);
 
@@ -510,27 +521,27 @@ remove_tag_for_urns (TrackerClient *client,
 		filter = get_filter_string (files, urn);
 
 		query = g_strdup_printf ("DELETE { "
-					 "  ?f nao:hasTag ?t "
-					 "} "
-					 "WHERE { "
-					 "  ?f nao:hasTag ?t ."
-					 "  %s "
-					 "}",
-					 filter);
+		                         "  ?f nao:hasTag ?t "
+		                         "} "
+		                         "WHERE { "
+		                         "  ?f nao:hasTag ?t ."
+		                         "  %s "
+		                         "}",
+		                         filter);
 		g_free (filter);
 #if 0
 		filter = get_filter_string (files);
 
-		query = g_strdup_printf ("DELETE {" 
-					 "  <%s> nao:hasTag ?tag "
-					 "} "
-					 "WHERE {"
-					 "  <%s> nao:hasTag ?tag"
-					 "  FILTER (?tag = <%s>)"
-					 "}",
-					 files[0],
-					 files[0],
-					 urn);
+		query = g_strdup_printf ("DELETE {"
+		                         "  <%s> nao:hasTag ?tag "
+		                         "} "
+		                         "WHERE {"
+		                         "  <%s> nao:hasTag ?tag"
+		                         "  FILTER (?tag = <%s>)"
+		                         "}",
+		                         files[0],
+		                         files[0],
+		                         urn);
 
 		g_ptr_array_foreach (results, (GFunc) g_strfreev, NULL);
 		g_ptr_array_free (results, TRUE);
@@ -538,12 +549,12 @@ remove_tag_for_urns (TrackerClient *client,
 	} else {
 		/* Remove tag completely */
 		query = g_strdup_printf ("DELETE { "
-					 "  ?tag a nao:Tag "
-					 "} "
-					 "WHERE {"
-					 "  ?tag nao:prefLabel %s "
-					 "}",
-					 tag_escaped);
+		                         "  ?tag a nao:Tag "
+		                         "} "
+		                         "WHERE {"
+		                         "  ?tag nao:prefLabel %s "
+		                         "}",
+		                         tag_escaped);
 	}
 
 	g_free (tag_escaped);
@@ -553,53 +564,53 @@ remove_tag_for_urns (TrackerClient *client,
 
 	if (error) {
 		g_printerr ("%s, %s\n",
-			    _("Could not remove tag"),
-			    error->message);
+		            _("Could not remove tag"),
+		            error->message);
 		g_error_free (error);
 
 		return FALSE;
 	}
 
 	g_print ("%s\n",
-		 _("Tag was removed successfully"));
+	         _("Tag was removed successfully"));
 
 	return TRUE;
 }
 
 static void
 get_tags_by_file_foreach (gpointer value,
-			  gpointer user_data)
+                          gpointer user_data)
 {
 	GStrv data = value;
 
 	g_print ("  %s\n", data[1]);
 }
 
-static gboolean 
-get_tags_by_file (TrackerClient *client, 
-		  const gchar   *file)
+static gboolean
+get_tags_by_file (TrackerClient *client,
+                  const gchar   *file)
 {
 	GError *error = NULL;
 	GPtrArray *results;
 	gchar *query;
 
 	query = g_strdup_printf ("SELECT ?tags ?labels "
-				 "WHERE {"
-				 "  <%s>"
-				 "  nao:hasTag ?tags ."
-				 "  ?tags a nao:Tag ;"
-				 "  nao:prefLabel ?labels "
-				 "} "
-				 "ORDER BY ASC(?labels)",
-				 file);
+	                         "WHERE {"
+	                         "  <%s>"
+	                         "  nao:hasTag ?tags ."
+	                         "  ?tags a nao:Tag ;"
+	                         "  nao:prefLabel ?labels "
+	                         "} "
+	                         "ORDER BY ASC(?labels)",
+	                         file);
 
 	results = tracker_resources_sparql_query (client, query, &error);
 	g_free (query);
 
 	if (error) {
 		g_printerr ("%s, %s\n",
-			    _("Could not get all tags"),
-			    error->message);
+		            _("Could not get all tags"),
+		            error->message);
 		g_error_free (error);
 
 		return FALSE;
@@ -607,25 +618,25 @@ get_tags_by_file (TrackerClient *client,
 
 	if (!results || results->len < 1) {
 		g_print ("  %s\n",
-			 _("No tags were found"));
+		         _("No tags were found"));
 	} else {
-		g_ptr_array_foreach (results, 
-				     get_tags_by_file_foreach,
-				     NULL);
+		g_ptr_array_foreach (results,
+		                     get_tags_by_file_foreach,
+		                     NULL);
 
 		g_ptr_array_foreach (results, (GFunc) g_strfreev, NULL);
 		g_ptr_array_free (results, TRUE);
 	}
-	
+
 	return TRUE;
 }
 
 int
 main (int argc, char **argv)
 {
-	TrackerClient	*client;
-	GOptionContext	*context;
-	const gchar	*failed = NULL;
+	TrackerClient   *client;
+	GOptionContext  *context;
+	const gchar     *failed = NULL;
 
 	setlocale (LC_ALL, "");
 
@@ -645,7 +656,7 @@ main (int argc, char **argv)
 	g_option_context_parse (context, &argc, &argv, NULL);
 
 	if (print_version) {
-                g_print ("\n" ABOUT "\n" LICENSE "\n");
+		g_print ("\n" ABOUT "\n" LICENSE "\n");
 		g_option_context_free (context);
 
 		return EXIT_SUCCESS;
@@ -678,7 +689,7 @@ main (int argc, char **argv)
 
 	if (!client) {
 		g_printerr ("%s\n",
-			    _("Could not establish a D-Bus connection to Tracker"));
+		            _("Could not establish a D-Bus connection to Tracker"));
 		return EXIT_FAILURE;
 	}
 
@@ -690,7 +701,7 @@ main (int argc, char **argv)
 
 		return success ? EXIT_SUCCESS : EXIT_FAILURE;
 	}
-	
+
 	if (add_tag) {
 		gboolean success;
 
@@ -727,7 +738,7 @@ main (int argc, char **argv)
 	tracker_disconnect (client);
 
 	/* This is a failure because we should have done something.
-	 * This code should never be reached in practise. 
-	 */ 
+	 * This code should never be reached in practise.
+	 */
 	return EXIT_FAILURE;
 }
